Crate passcore

Crate passcore 

Modules

score

Functions

grade_password
The grade_password function takes a password as input and outputs a letter grade.
The grade_password function will never log your password
review_password
The review_password function takes a password as input and outputs suggestions for improvement.
The review_password function will never log your password
score
The score function takes a password as input and outputs a score.
It makes use of 4 scoring functions located in the score.rs file.
The score function will never log your password